@@ -152,7 +152,7 @@ def decompress_all_zip_files(start_path,**kwargs):
                     dst = f"{zf['dir_path']}/{zf['name_no_ext']}"
                     if directory.exists(dst) is False:
                         directory.create(dst)
-                        
+
                     decompress_single_zip_file(zf['file_path'],dst,delete_after=delete_after)
                     extracted.append(zf['file_path'])
     else:
@@ -200,7 +200,7 @@ def _filter_extracted(files,extracted):
             new_files.append(zf)
     return new_files
 
-def decompress_single_zip_file(src,dst,**kwargs):
+def decompress_single_zip_file(src,dst=None,**kwargs):
     '''
         Decompress a single zip or rar file.
 
@@ -216,7 +216,7 @@ def decompress_single_zip_file(src,dst,**kwargs):
 
         Keyword Arguments
         -------------------------
-        [`delete_after`=True] {bool}
+        [`delete_after`=False] {bool}
             If True, the zip file will be deleted after its contents are extracted.
 
         Return {bool}
@@ -230,13 +230,25 @@ def decompress_single_zip_file(src,dst,**kwargs):
         `memberOf`: file_compression
         `version`: 1.0
         `method_name`: decompress_single_zip_file
-        # @TODO []: documentation for decompress_single_zip_file
+        # @xxx [03\26\2022 10:14:59]: documentation for decompress_single_zip_file
     '''
-    delete_after = obj.get_kwarg(["delete after"], True, (bool), **kwargs)
+    delete_after = obj.get_kwarg(["delete after"], False, (bool), **kwargs)
+    valid_ext = ['.zip','.rar']
+
+    src_data = file.get_data(src)
+    if src_data['extension'] not in ['.zip','.rar']:
+        print(f"Invalid zip extension {src_data['extension']}.")
+        print(f"Supported extensions: {valid_ext}")
+        return False
+
+
+    if dst is None:
+        dst = f"{src_data['dir_path']}\\{src_data['name_no_ext']}"
 
 
     src = csu.format.file_path(src)
     dst = csu.format.file_path(dst)
+    directory.create(dst)
 
     src_ext = file.get_ext(src)
 
